.. _spot-faq:

++++
FAQs
++++

This section contains some frequently asked questions (FAQs) regarding
SPOT usage.

---------
Platforms
---------

Does SPOT run on Mac/Windows/Linux/XYZ?
----------------------------------------
SPOT is written entirely in the Python programming language, and uses only
supporting Python packages.  As long as a platform supports Python
and the necessary packages, it can run SPOT.

